# -*- coding: utf-8 -*-

from django.apps import AppConfig


class ComuniItalianiAutocompleteConfig(AppConfig):
    name = 'comuni_italiani.autocomplete'
    verbose_name = "Comuni Italiani Autocomplete"
